# UsefulGenPy
A Python Module containing time-saving generators. The code as got a lot of Docstrings don't hesitate to check those if needed.

<br>

**Please star this repository if you find it useful** ⭐ <br> 
Don't hesitate to reach me, or donate using the links on <a href="https://github.com/M4elstr0m/">my profile</a>, all donations are appreciated 😉

<br>

## 🛠️ Installation
**Please install Python 3 and be sure that you also have "pip" installed on your machine**<br>
```bash
pip3 install usefulgen
```

<br>

If you don't have **pip** installed yet, just type the command ```py -m ensurepip --upgrade```

## 🧩 Features
<div>
<table>
  <tr>
    <th>Feature</th>
    <th>Supported</th>
    <th>Software Version</th>
  </tr>
  <tr>
    <td>Basic time-saving generators from numbers to strings</td>
    <td>✅</td>
    <td>v1.0.1.1</td>
  </tr>
  <tr>
    <td>Wordlists generators</td>
    <td>✅</td>
    <td>v1.0.2</td>
  </tr>
  <tr>
    <td>Prefixes/Suffixes on Wordlists output</td>
    <td>✅</td>
    <td>v1.0.3</td>
  </tr>
  <tr>
    <td>Email Address generator</td>
    <td>🚧</td>
    <td>v1.0.?</td>
  </tr>
</table>
</div>
